# tdm-kevin

`tdm-kevin` is an example package for The Data Mine at Purdue University.

## Installation

```bash
python3 -m pip install tdm-kevin
```

## How to run the server

```bash
# incomplete
```